# Installation

## Stable release

To install, run this command in your terminal:

```bash
pip install CNICA
```

or

```bash
conda install -c Ivancic91 CNICA
```

This is the preferred method to install, as it will always install the most
recent stable release.

## From sources

See [](./contributing) for details on installing from source.
